@@ -41,7 +41,7 @@ use namespace::autoclean;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = 'v0.8.4'; # VERSION
+our $VERSION = 'v0.8.5'; # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -339,7 +339,7 @@ sub configure {
             'hook' => [ q{
                 use Path::Tiny;
                 my $file = path( $zilla->root )->child( 'VERSION' );
-                my $version = $file->slurp =~ s{\s+\z}{}r;
+                ( my $version = $file->slurp ) =~ s{\s+\z}{};
                 if ( $version !~ m{\A@{ [ Perl::Version::REGEX ] }\z} ) {
                     $self->abort( [
                         'Invalid version string "%s" at %s line 1', $version, "$file"
@@ -395,7 +395,7 @@ sub configure {
                     q[        ->chomp;                                                              ],
                     #   Resulting file may have one or two empty lines at the end, it affects
                     #   testing. Let's try to chomp empty lines to avoid it.
-                    q[}] . q[}],
+                    q[}] . q[}],        # One newline will be added there.
                 ],
             } ],
         ) : (
@@ -406,18 +406,19 @@ sub configure {
                 'filename' => 'README',
                 'content'  => [
                     q[{] . q[{],
-                    q[    my @parts;                                                                       ],
-                    q[    for my $file ( ] . $self->_quote( $self->readme ) . q[ ) {                       ],
-                    q[        push( @parts,                                                                ],
-                    q[            include( MY::file( $plugin, $file ) )                                    ],
+                    q[join(                                                                                ],
+                    q[    "\n\n",                                                                          ],
+                    q[    map(                                                                             ],
+                    q[        {                                                                            ],
+                    q[            include( MY::file( $plugin, $_ ) )                                       ],
                     q[                ->fill_in                                                            ],
                     q[                ->pod2text( width => 80, indent => 0, loose => 1, quotes => 'none' ) ],
-                    q[                ->chomp .                                                            ],
-                    q[            "\n",                                                                    ],
-                    q[        );                                                                           ],
-                    q[    };                                                                               ],
-                    q[    join( "\n", @parts );                                                            ],
-                    q[}] . q[}],
+                    q[                ->chomp                                                              ],
+                    q[        }                                                                            ],
+                    q[    ] . $self->_quote( $self->readme ) . q[                                          ],
+                    q[    )                                                                                ],
+                    q[);                                                                                   ],
+                    q[}] . q[}],        # One newline will be added there.
                 ],
             } ],
         ) : (
@@ -935,7 +936,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version v0.8.4, released on 2015-09-27 08:14 UTC.
+Version v0.8.5, released on 2015-09-27 13:43 UTC.
 
 =head1 WHAT?
 
